==> catseye-fm-3.0.0.0.tar.gz: catseye-fm-3.0.0.0/myfm.h <==
/*
    Copyright 2007, 2008, 2009 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef MYFM_H_
#define MYFM_H_

gboolean oneKeyPressedOnNotebook(GtkWidget *widget, GdkEventKey *event, gpointer data);
void oneRowActivated(struct AllInformationAllUseStruct *stru);
int mysortfunctionforText(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
int mysortfunctionshelperForCaseInsensitiveComparission(gchar *string1, gchar *string2, GtkSortType sortOrder);
int mysortfunctionforNumbers(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
int mysortfunctionforBigNumbers(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
void updateViewWithNewFolder(struct SideObjectList *Object, GString *NewPath);
void freeTypesAndUserProgrammArrays();
void getStandardEditor();
void getTerminal();
void getTypesOfSelectedItems(gpointer data);
void getUserProgramsForSelectedItems(gpointer data);
int checkIfOneSelectionIsPoints(gpointer data, int ColoumnToUse);
void getUserProgramsForCountForAllItems(gpointer data);
void callAllWithHelper(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter *iter,gpointer data);
void callAllWith (GtkWidget *menuitem, gpointer data);
void searchStringInAndHighlightItems(GtkWidget *menuitem, gpointer data);
void sizeOfSelectedItemsRecursive (GtkWidget *menuitem, gpointer data);
int checkIfOneSelectionIsPath(gpointer data, int ColoumnToUse);
void renameItemsHelper(GtkTreeSelection	*selection, struct AllInformationAllUseStruct *info);
void callEachWith_Menuitem(GtkWidget *menuitem, gpointer data);
void startItemsWithUserCommand(GtkWidget *menuitem, gpointer data);
gboolean oneMouseButtonPressedOnNotebook(GtkWidget *notebook, GdkEventButton *event, gpointer data);
int predefine_NotebookTaps_Objects(struct SideObjectList *Object);
int connectSignalsToNotebookTapObject(struct SideObjectList *Object);
void updateObjectsViewingFolder(char *Folder, gboolean automaticTriggered);
void updateViewWithNewFolder_UserAdvice(struct SideObjectList *Object, GString *NewPath);
gboolean updateViewsFolder_Helper (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, struct AllInformationAllUseStruct *infostru);
void updateStatusBar(struct SideObjectList *Object);
void copyToAnOtherPannel(struct SideObjectList *sourceObject, struct SideObjectList *destObject);
void updateActiveViews();
void updateView(struct SideObjectList *Object);
int checkIfFolderNeedsUpdate(struct SideObjectList *Object);
void MenuAddItemToFileshelf(GtkWidget *menuitem, gpointer data);

enum {
	COL_NAME = 0,
	COL_SIZE,
	COL_OWNER,
	COL_GROUP,
	COL_PERMISSION,
	COL_ACCESSED,
	COL_CHANGED,
	COL_TARGET,     //if the item is a link, here is what it points to
	COL_FILETYPE,	//For e.g. for picture or video file this means jpg, mp3 and so on
	COL_TIMESTAMPACCESSED,	//untouched timevalue from files
	COL_TIMESTAMPCHANGED,
	COL_TYPE_D,	//is it file, directory, link and so on, see 'man dirent'
	COL_COLOR,
	NUM_COLS
};


enum{	//for the source-member in AllInformationAllUseStruct
	SOURCE_SIDEOBJECT = 0,
	SOURCE_FILESHELF
};

#endif	//MYFM_H_

==> catseye-fm-4.2.0.0.tar.gz: catseye-fm-4.2.0.0/myfm.h <==
/*
    Copyright 2007, 2008, 2009, 2010 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef MYFM_H_
#define MYFM_H_

gboolean oneKeyPressedOnNotebook(GtkWidget *widget, GdkEventKey *event, gpointer data);
void oneRowActivated(struct AllInformationAllUseStruct *stru);
int mysortfunctionforText(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
int mysortfunctionshelperForCaseInsensitiveComparission(gchar *string1, gchar *string2, GtkSortType sortOrder);
int mysortfunctionforNumbers(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
int mysortfunctionforBigNumbers(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
void updateViewWithNewFolder(struct SideObjectList *Object, GString *NewPath);
void getStandardEditor();
void getTerminal();
GList *getTypesOfSelectedItems(struct AllInformationAllUseStruct *info);
int getUserProgramsForSelectedItems(GList *glistMarkedTypes, struct UserDataList **theUserDataList);
int checkIfOneSelectionIsPoints(gpointer data, int ColoumnToUse);
void CallUsersDummyCommand (void *Object, int iSource, int iCallType);
void searchStringInAndHighlightItems(GtkWidget *menuitem, gpointer data);
void sizeOfSelectedItemsRecursive (GtkWidget *menuitem, gpointer data);
int checkIfOneSelectionIsPath(gpointer data, int ColoumnToUse);
void renameItemsHelper(GtkTreeSelection	*selection, struct AllInformationAllUseStruct *info);
void callEachWith_Menuitem(GtkWidget *menuitem, gpointer data);
void startItemsWithUserCommand(GtkWidget *menuitem, struct UserDataList *UserDataListItem);
void CallUsersDummyCommand (void *Object, int iSource, int iCallType);
gboolean oneMouseButtonPressedOnNotebook(GtkWidget *notebook, GdkEventButton *event, gpointer data);
int predefine_NotebookTaps_Objects(struct SideObjectList *Object);
int connectSignalsToNotebookTapObject(struct SideObjectList *Object);
void updateObjectsViewingFolder(char *Folder, gboolean automaticTriggered);
void updateViewWithNewFolder_UserAdvice(struct SideObjectList *Object, GString *NewPath);
gboolean updateViewsFolder_Helper (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, struct AllInformationAllUseStruct *infostru);
void updateStatusBar(struct SideObjectList *Object);
void copyToAnOtherPannel(struct SideObjectList *sourceObject, struct SideObjectList *destObject);
void updateActiveViews();
void updateView(struct SideObjectList *Object);
int checkIfFolderNeedsUpdate(struct SideObjectList *Object);
void MenuAddItemToFileshelf(GtkWidget *menuitem, gpointer data);
int MakeList (int Source, struct CopyReMoveList **FirstItem, GtkTreeSelection *selection, GString *SourcePath, GString *gstrDestPath);
gboolean oneMouseButtonPressed(GtkWidget *treeview, GdkEventButton *event, gpointer data);
GdkPixbuf *getPreviewPixBufForFile (const char *ccpPath, const char *ccpFilename);
int predefine_NotebookTabs_reorderColumns (GtkTreeView *treeview);
void reorderAllTabsColumns ();

enum {
    COL_PREVIEW=0,
	COL_NAME,
	COL_SIZE,
	COL_OWNER,
	COL_GROUP,
	COL_PERMISSION,
	COL_ACCESSED,
	COL_CHANGED,
	COL_TARGET,     //if the item is a link, here is what it points to
	COL_FILETYPE,	//For e.g. for picture or video file this means jpg, mp3 and so on
	COL_TIMESTAMPACCESSED,	//untouched timevalue from files
	COL_TIMESTAMPCHANGED,
	COL_TYPE_D,	//is it file, directory, link and so on, see 'man dirent'
	COL_COLOR,
	NUM_COLS
};


#endif	//MYFM_H_
